@@ -22,10 +22,23 @@ from rex.utilities.utilities import dict_str_load
 logger = logging.getLogger(__name__)
 
 
-@click.command()
+@click.group()
+@click.option('--name', '-n', default='reV-agg', type=STR,
+              help='Job name. Default is "reV-agg".')
+@click.option('-v', '--verbose', is_flag=True,
+              help='Flag to turn on debug logging. Default is not verbose.')
+@click.pass_context
+def main(ctx, name, verbose):
+    """reV Supply Curve Aggregation Command Line Interface"""
+    ctx.ensure_object(dict)
+    ctx.obj['NAME'] = name
+    ctx.obj['VERBOSE'] = verbose
+
+
+@main.command()
 @click.option('--config_file', '-c', required=True,
               type=click.Path(exists=True),
-              help='reV exclusions configuration json file.')
+              help='reV aggregation configuration json file.')
 @click.option('-v', '--verbose', is_flag=True,
               help='Flag to turn on debug logging. Default is not verbose.')
 @click.pass_context
@@ -40,13 +53,15 @@ def from_config(ctx, config_file, verbose):
     if config.name.lower() != 'rev':
         name = config.name
 
+    ctx.obj['NAME'] = name
+
     # Enforce verbosity if logging level is specified in the config
     if config.log_level == logging.DEBUG:
         verbose = True
 
     # initialize loggers
     init_mult(name, config.logdir, modules=[__name__, 'reV.config',
-                                            'reV.utilities'],
+                                            'reV.utilities', 'rex.utilities'],
               verbose=verbose)
 
     # Initial log statements
@@ -67,8 +82,7 @@ def from_config(ctx, config_file, verbose):
                 job_attrs={'hardware': 'local',
                            'fout': '{}.csv'.format(name),
                            'dirout': config.dirout})
-            ctx.invoke(main,
-                       name=name,
+            ctx.invoke(direct,
                        excl_fpath=config.excl_fpath,
                        gen_fpath=config.gen_fpath,
                        res_fpath=config.res_fpath,
@@ -123,9 +137,7 @@ def from_config(ctx, config_file, verbose):
                    module=config.execution_control.module)
 
 
-@click.group(invoke_without_command=True)
-@click.option('--name', '-n', default='agg', type=STR,
-              help='Job name. Default is "agg".')
+@main.group(invoke_without_command=True)
 @click.option('--excl_fpath', '-ef', type=STR, required=True,
               help='Exclusions file (.h5).')
 @click.option('--gen_fpath', '-gf', type=STR, required=True,
@@ -182,14 +194,13 @@ def from_config(ctx, config_file, verbose):
 @click.option('-v', '--verbose', is_flag=True,
               help='Flag to turn on debug logging. Default is not verbose.')
 @click.pass_context
-def main(ctx, name, excl_fpath, gen_fpath, res_fpath, tm_dset, excl_dict,
-         check_excl_layers, res_class_dset, res_class_bins, cf_dset, lcoe_dset,
-         data_layers, resolution, power_density, area_filter_kernel, min_area,
-         friction_fpath, friction_dset, out_dir, log_dir, verbose):
+def direct(ctx, excl_fpath, gen_fpath, res_fpath, tm_dset, excl_dict,
+           check_excl_layers, res_class_dset, res_class_bins, cf_dset,
+           lcoe_dset, data_layers, resolution, power_density,
+           area_filter_kernel, min_area, friction_fpath, friction_dset,
+           out_dir, log_dir, verbose):
     """reV Supply Curve Aggregation Summary CLI."""
-
-    ctx.ensure_object(dict)
-    ctx.obj['NAME'] = name
+    name = ctx.obj['NAME']
     ctx.obj['EXCL_FPATH'] = excl_fpath
     ctx.obj['GEN_FPATH'] = gen_fpath
     ctx.obj['RES_FPATH'] = res_fpath
@@ -282,8 +293,7 @@ def get_node_cmd(name, excl_fpath, gen_fpath, res_fpath, tm_dset, excl_dict,
                  out_dir, log_dir, verbose):
     """Get a CLI call command for the SC aggregation cli."""
 
-    args = ('-n {name} '
-            '-ef {excl_fpath} '
+    args = ('-ef {excl_fpath} '
             '-gf {gen_fpath} '
             '-rf {res_fpath} '
             '-tm {tm_dset} '
@@ -303,8 +313,7 @@ def get_node_cmd(name, excl_fpath, gen_fpath, res_fpath, tm_dset, excl_dict,
             '-ld {log_dir} '
             )
 
-    args = args.format(name=SLURM.s(name),
-                       excl_fpath=SLURM.s(excl_fpath),
+    args = args.format(excl_fpath=SLURM.s(excl_fpath),
                        gen_fpath=SLURM.s(gen_fpath),
                        res_fpath=SLURM.s(res_fpath),
                        tm_dset=SLURM.s(tm_dset),
@@ -330,11 +339,13 @@ def get_node_cmd(name, excl_fpath, gen_fpath, res_fpath, tm_dset, excl_dict,
     if verbose:
         args += '-v '
 
-    cmd = 'python -m reV.supply_curve.cli_sc_aggregation {}'.format(args)
+    cmd = ('python -m reV.supply_curve.cli_sc_aggregation -n {} direct {}'
+           .format(SLURM.s(name), args))
+
     return cmd
 
 
-@main.command()
+@direct.command()
 @click.option('--alloc', '-a', required=True, type=STR,
               help='SLURM allocation account name.')
 @click.option('--walltime', '-wt', default=1.0, type=float,
@@ -354,7 +365,6 @@ def get_node_cmd(name, excl_fpath, gen_fpath, res_fpath, tm_dset, excl_dict,
 def slurm(ctx, alloc, walltime, feature, memory, module, conda_env,
           stdout_path):
     """slurm (Eagle) submission tool for reV supply curve aggregation."""
-
     name = ctx.obj['NAME']
     excl_fpath = ctx.obj['EXCL_FPATH']
     gen_fpath = ctx.obj['GEN_FPATH']
