@@ -578,24 +578,29 @@ class SupplyCurve:
         comp_wind_dirs : CompetitiveWindFarms
             updated CompetitiveWindFarms instance
         """
-        gid = comp_wind_dirs['sc_point_gid', sc_gid]
-        if comp_wind_dirs.mask[gid]:
-            upwind_gids = comp_wind_dirs['upwind', gid]
-            for n in upwind_gids:
-                check = comp_wind_dirs.exclude_sc_point_gid(n)
-                if check:
-                    sc_gids = comp_wind_dirs['sc_gid', n]
-                    for sc_id in sc_gids:
-                        self._mask[sc_id] = False
+        gid = comp_wind_dirs.check_sc_gid(sc_gid)
+        if gid is not None:
+            if comp_wind_dirs.mask[gid]:
+                upwind_gids = comp_wind_dirs['upwind', gid]
+                for n in upwind_gids:
+                    check = comp_wind_dirs.exclude_sc_point_gid(n)
+                    if check:
+                        sc_gids = comp_wind_dirs['sc_gid', n]
+                        for sc_id in sc_gids:
+                            logger.debug('Excluding upwind sc_gid {}'
+                                         .format(sc_id))
+                            self._mask[sc_id] = False
 
-        if downwind:
-            downwind_gids = comp_wind_dirs['downwind', gid]
-            for n in downwind_gids:
-                check = comp_wind_dirs.exclude_sc_point_gid(n)
-                if check:
-                    sc_gids = comp_wind_dirs['sc_gid', n]
-                    for sc_id in sc_gids:
-                        self._mask[sc_id] = False
+            if downwind:
+                downwind_gids = comp_wind_dirs['downwind', gid]
+                for n in downwind_gids:
+                    check = comp_wind_dirs.exclude_sc_point_gid(n)
+                    if check:
+                        sc_gids = comp_wind_dirs['sc_gid', n]
+                        for sc_id in sc_gids:
+                            logger.debug('Excluding downind sc_gid {}'
+                                         .format(sc_id))
+                            self._mask[sc_id] = False
 
         return comp_wind_dirs
 
@@ -707,7 +712,7 @@ class SupplyCurve:
     def full_sort(self, trans_table=None, sort_on='total_lcoe',
                   columns=('trans_gid', 'trans_capacity', 'trans_type',
                            'trans_cap_cost', 'dist_mi', 'lcot', 'total_lcoe'),
-                  wind_dirs=None, n_dirs=2, downwind=False):
+                  wind_dirs=None, n_dirs=2, downwind=False, offshore=False):
         """
         run full supply curve sorting
 
@@ -731,6 +736,9 @@ class SupplyCurve:
         downwind : bool, optional
             Flag to remove downwind neighbors as well as upwind neighbors,
             by default False
+        offshore : bool
+            Flag as to whether offshore farms should be included during
+            CompetitiveWindFarms
 
         Returns
         -------
@@ -754,8 +762,20 @@ class SupplyCurve:
 
         comp_wind_dirs = None
         if wind_dirs is not None:
-            comp_wind_dirs = CompetitiveWindFarms(wind_dirs, self._sc_points,
-                                                  n_dirs=n_dirs)
+            msg = "Excluding {} upwind".format(n_dirs)
+            if downwind:
+                msg += " and downwind"
+
+            msg += " onshore"
+            if offshore:
+                msg += " and offshore"
+
+            msg += " windfarms"
+            logger.info(msg)
+            comp_wind_dirs = CompetitiveWindFarms(wind_dirs,
+                                                  self._sc_points,
+                                                  n_dirs=n_dirs,
+                                                  offshore=offshore)
 
         supply_curve = self._full_sort(trans_table,
                                        comp_wind_dirs=comp_wind_dirs,
